Struct mumble_link::SharedLink [] [src]

pub struct SharedLink { /* fields omitted */ }

A weak Mumble link connection.

Constructing a SharedLink always succeeds, even if Mumble is not running or another application is writing to the link. If this happens, update() will retry opening the link on a regular basis, succeeding if Mumble is started or the other application stops using the link.

Methods

impl SharedLink
[src]

Open the Mumble link, providing the specified application name and description.

Update the context string, used to determine which users on a Mumble server should hear each other positionally.

If context between two Mumble users does not match, the positional audio data is stripped server-side and voice will be received as non-positional. Accordingly, the context should only match for players on the same game, server, and map, depending on the game itself. When in doubt, err on the side of including less; this allows for more flexibility in the future.

The context should be changed infrequently, at most a few times per second.

The context has a maximum length of 256 bytes.

Update the identity, uniquely identifying the player in the given context. This is usually the in-game name or ID.

The identity may also contain any additional information about the player which might be useful for the Mumble server, for example to move teammates to the same channel or give squad leaders additional powers. It is recommended that a parseable format like JSON or CSV is used for this.

The identity should be changed infrequently, at most a few times per second.

The identity has a maximum length of 255 UTF-16 code units.

Update the link with the latest position information. Should be called once per frame.

avatar should be the position of the player. If it is all zero, positional audio will be disabled. camera should be the position of the camera, which may be the same as avatar.

Get the status of the shared link. See Status for details.

Deactivate the shared link.

Should be called when update() will not be called again for a while, such as if the player is no longer in-game.